@@ -1,9 +1,8 @@
+pub use crate::compiled_program::*;
 pub use crate::compiler::{
-    compile, CaoIr, Card, CompilationError, CompilationErrorPayload, CompileOptions, Lane,
+    compile, CaoProgram, Card, CompilationError, CompilationErrorPayload, CompileOptions, Lane,
 };
-pub use crate::instruction::Instruction;
 pub use crate::procedures::*;
-pub use crate::program::*;
 pub use crate::traits::*;
 pub use crate::value::*;
 pub use crate::{
