@@ -48,7 +48,7 @@ impl<'a, Aux> Vm<'a, Aux> {
     }
 
     /// Inserts the given value into the VM's runtime memory. Returns the inserted [[Value]]
-    pub fn insert_value(&mut self, value: OwnedValue) -> Result<Value, ExecutionErrorPayload> {
+    pub fn insert_value(&mut self, value: &OwnedValue) -> Result<Value, ExecutionErrorPayload> {
         let res = match value {
             OwnedValue::Nil => Value::Nil,
             OwnedValue::String(s) => {
@@ -57,17 +57,17 @@ impl<'a, Aux> Vm<'a, Aux> {
             }
             OwnedValue::Object(o) => {
                 let mut res = self.init_table()?;
-                for [k, v] in o.into_iter() {
-                    let k = self.insert_value(k)?;
-                    let v = self.insert_value(v)?;
+                for OwnedEntry { key, value } in o.into_iter() {
+                    let key = self.insert_value(key)?;
+                    let value = self.insert_value(value)?;
                     unsafe {
-                        res.as_mut().insert(k, v)?;
+                        res.as_mut().insert(key, value)?;
                     }
                 }
                 Value::Object(res.as_ptr())
             }
-            OwnedValue::Integer(x) => Value::Integer(x),
-            OwnedValue::Real(x) => Value::Real(x),
+            OwnedValue::Integer(x) => Value::Integer(*x),
+            OwnedValue::Real(x) => Value::Real(*x),
         };
         Ok(res)
     }
